import subprocess
from enum import Enum
from .paths import seasons
import random

# import mpv
import tempfile
import os


class Stream(str, Enum):
    KEXP = "kexp"
    KUGS = "kugs"
    CLIS = "clis"


def play(stream):
    """Play streams using mpv."""
    match stream:
        case Stream.KEXP:
            url = "https://kexp-mp3-128.streamguys1.com/kexp128.mp3"
        case Stream.KUGS:
            url = "https://peridot.streamguys1.com:7175/kugs-mp3"
        case Stream.CLIS:
            url = "https://stream2.statsradio.com:8012/stream?=&&___cb=759135934160766"
        case _:
            raise ValueError(f"unrecognized stream: {stream}")
    subprocess.run(["mpv", url])


def local():
    """play random local songs."""
    songs = []
    for d in seasons():
        for f in d.iterdir():
            if not f.suffix == ".mp3":
                continue
            songs.append(f)
    random.shuffle(songs)
    with tempfile.NamedTemporaryFile(delete=False, suffix=".txt") as tmp:
        for song in songs:
            tmp.write(f"{song}\n".encode())
        playlist = tmp.name
        # fd -t file -e mp3 -p -a "fall|winter|spring|summer" $HOME/Music/ | mpv --playlist=- --shuffle --no-video

    try:
        subprocess.run(["mpv", f"--playlist={playlist}", "--shuffle", "--no-video"])
        # process = subprocess.Popen(
        #     ["mpv", f"--playlist={playlist}", "--shuffle", "--no-video"],
        # )

        # process.wait()
    finally:
        os.remove(playlist)
